// Simple parametric tablet stand
// 2023 by Rainer Backes

include <BOSL2/std.scad>
include <BOSL2/hinges.scad>
use <hexa.scad>

// Thickness of the legs
thick = 4;
// Angle for the tablet
angle = 60; // neigung des Pad
// Tickness of tablett
ipthick = 7; // dicke iPad
// thickness of cover -> 0 no cover
coverthick = 5; // dicke Cover
// how much overlaps the cover the tablet
cov_overlap = 2; // Überstand cover über Pad
// additional tolerance
cov_tol = 1; // Zusätzlicher Freiraum
// height of the cutout
cutout_h = 10; // Höhe Cutout über Achse
// thickness of the holding nock
nock_thick = 10; // Dicke Nock (Achse)
// Heigh of the nock over cutout
nock_add = 20; 
// total Heigth
support_hi = 50; // gesamthöhe
// len of the legs
totlen = 170; // totale länge
// Heigth at the hinge
back_hi = 20; // Höhe hinten
// len of the even part before the hinge
back_even = 20;
// thickness of the side walls
sidewall = 3;
// size of the hexagons
hexsize = 8;
// wall thicknes of the hexagons
hexwall = 1;
// tolerance for the holes of the hinge, 0.2 recommended
$slop = 0.2;

/* [Hidden] */
front_angle=min ( 90, angle+10) ; // vorderer Ausschnitt
front_rad = 4; // radius front 
nock_hi = cutout_h+nock_add; // höhe Nock
nock_rad = 8 * (10/nock_thick) ; //Radius Nock high

// some math ...
p3x = totlen - nock_hi / tan(front_angle);
co_w = ipthick+coverthick+cov_tol;
p4x = p3x - nock_thick;
p5y = cutout_h + co_w * sin(90-angle);
p5x=  p4x + (nock_hi-p5y) / tan(front_angle); 
p6y = cutout_h; 
p6x = p5x - co_w * sin ( angle);

p53x = p6x + coverthick * sin(angle);
p53y = p6y + coverthick * cos(angle);
p52x = p53x - cov_overlap * sin(90-angle);
p52y = p53y + cov_overlap * cos(90-angle);
p51x = p52x+ (ipthick+cov_tol) * sin(angle);
p51y = p52y + (ipthick+cov_tol) * cos(angle);


// angles at p7 for rounding
p7x = p6x - ((support_hi-cutout_h) / tan(angle));
p7lang = atan ((p7x-back_even)/(support_hi-back_hi));
p7ang = (90 - angle) + atan ((p7x-back_even)/(support_hi-back_hi));

// projection of p6 to the x axis for cutout
p6xdn = p7x + (support_hi / tan(angle) );





eps = 0.001;  // small number, to keep scad happy


res= $preview ? 32 : 128;
$fn=res;


module leg(left = true) {
difference() {
	// outer shape
	linear_extrude ( thick)
		polygon( [	[0,0], 							// P1
					[totlen,0],   					// P2
					[p3x	, nock_hi], 			// P3
					[p3x - nock_thick, nock_hi],  	// P4
					[p51x,p51y],
					[p52x,p52y],
					[p53x,p53y],
//					[p5x,p5y],						// P5
					[p6x,p6y],						// P6
					[p7x,support_hi],				// P7
					[back_even,back_hi],			// P8	
					[0,back_hi] ]);					// P9
				
	// cutout for the hex
	translate([0,0,-0.5])
		linear_extrude ( thick+1)
			offset(delta= -sidewall)
				polygon( [	[back_even,0],  
							[p6xdn,0],
							[p7x,support_hi],
							[back_even,back_hi]]);
			
	
	// some rounding
	translate([totlen,0,0]) 
        fillet(l=thick, r=front_rad,spin = 90 + (90-front_angle),ang=front_angle, anchor=BOTTOM  );
	translate([p3x	, nock_hi+eps,0])
		fillet(l=thick, r=nock_rad, spin = 180, ang=180-front_angle, anchor=BOTTOM );
	translate([p3x - nock_thick, nock_hi,0])
		fillet(l=thick, r=1, spin = -front_angle , ang=front_angle, anchor=BOTTOM );
	translate([p7x,support_hi,0])
		fillet(l=thick, r=2, spin = -(90+p7lang), ang=p7ang, anchor=BOTTOM );
	
	// chamfer for the hinge
	translate([0,-1,thick+eps])
		rotate([270,0,0])
		linear_extrude(back_hi+2) right_triangle([6,thick/2]);
	}
	
	// the hex
	intersection() {
		translate([p6xdn/2,sidewall-hexsize-hexwall,0])
			hexarea(radius=p6xdn/2 +10,hexsize=hexsize, hexwall=hexwall, h=thick);
		translate([0,0,-0.5])
			linear_extrude ( thick+1)
				offset(delta= -sidewall+eps)
					polygon( [	[back_even,0],  
								[p6xdn,0],
								[p7x,support_hi],
								[back_even,back_hi]]);
	}
	// the hinge
	translate([1,1,thick-1.7])
		knuckle_hinge(length=back_hi-1, segs=5, offset=3, arm_height=0,spin = 90, orient=UP,knuckle_diam= 5,inner=left,anchor=BOTTOM+LEFT);

}

translate([0,support_hi+10 ,0]) {
leg(false);
}

translate([totlen,0,0]) {
  mirror([1,0,0]) { 
  leg(true);
}}